#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
check_talend_job
------------------------------
A nagios-like plugin to check if talend jobs executed successfully

"""

__docformat__ = 'restructuredtext en'

from .check_talend_job import main
# vim:set et sts=4 ts=4 tw=80:
